@@ -1,6 +1,8 @@
 from __future__ import annotations
 
 from plume.proxy.unity.component.component import Component
-from plume.proxy.unity.component.component_collection import ComponentCollection
+from plume.proxy.unity.component.component_collection import (
+    ComponentCollection,
+)
 
-__all__ = [Component, ComponentCollection]
\ No newline at end of file
+__all__ = [Component, ComponentCollection]
