@@ -8,14 +8,13 @@ from uuid import UUID
 
 
 class XRBaseInteractor(Component):
-
     _enabled: bool = True
 
     def __init__(
         self,
         guid: Union[str, UUID],
         game_object: GameObject,
-        enabled: bool = True
+        enabled: bool = True,
     ):
         super().__init__(guid, game_object)
         self._enabled = enabled
