@@ -21,7 +21,9 @@ class Scene:
         self._guid = UUID(guid) if isinstance(guid, str) else guid
         self._name = name
         self._asset_bundle_path = asset_bundle_path
-        self._game_objects = game_objects if game_objects else GameObjectCollection()
+        self._game_objects = (
+            game_objects if game_objects else GameObjectCollection()
+        )
 
     @property
     def guid(self) -> UUID:
@@ -40,4 +42,4 @@ class Scene:
         return self._game_objects
 
     def __repr__(self) -> str:
-        return f"Scene(guid={self._guid}, name={self._name}, n_game_objects={len(self._game_objects)})"
\ No newline at end of file
+        return f"Scene(guid={self._guid}, name={self._name}, n_game_objects={len(self._game_objects)})"
